# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2017-10-14 07:06
from __future__ import unicode_literals

import ckeditor_uploader.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('articles', '0003_auto_20171005_0636'),
    ]

    operations = [
        migrations.CreateModel(
            name='ArticleTag',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('text', models.CharField(max_length=255, unique=True, verbose_name='Text')),
            ],
            options={
                'verbose_name': 'Article tag',
                'verbose_name_plural': 'Article tags',
            },
        ),
        migrations.AlterModelOptions(
            name='article',
            options={'ordering': ['-created'], 'verbose_name': 'Article', 'verbose_name_plural': 'Articles'},
        ),
        migrations.AlterField(
            model_name='article',
            name='created',
            field=models.DateTimeField(db_index=True, verbose_name='Created'),
        ),
        migrations.AlterField(
            model_name='article',
            name='description',
            field=models.CharField(max_length=255, verbose_name='Description'),
        ),
        migrations.AlterField(
            model_name='article',
            name='is_comments_enabled',
            field=models.BooleanField(default=True, verbose_name='Is comments enabled'),
        ),
        migrations.AlterField(
            model_name='article',
            name='text',
            field=ckeditor_uploader.fields.RichTextUploadingField(max_length=50000, verbose_name='Text'),
        ),
        migrations.AlterField(
            model_name='article',
            name='title',
            field=models.CharField(max_length=255, verbose_name='Title'),
        ),
        migrations.AlterField(
            model_name='article',
            name='type',
            field=models.CharField(choices=[(b'news', 'News')], default=None, max_length=255, verbose_name='Type'),
        ),
        migrations.AddField(
            model_name='article',
            name='tags',
            field=models.ManyToManyField(blank=True, related_name='tags', to='articles.ArticleTag', verbose_name='Tags'),
        ),
    ]
