# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2017-07-03 15:14
from __future__ import unicode_literals

import ckeditor_uploader.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('articles', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='article',
            options={'ordering': ['-id'], 'verbose_name': '\u0421\u0442\u0430\u0442\u0442\u044f', 'verbose_name_plural': '\u0421\u0442\u0430\u0442\u0442\u0456'},
        ),
        migrations.AddField(
            model_name='article',
            name='created',
            field=models.DateTimeField(auto_now=True, db_index=True, verbose_name='Created'),
        ),
        migrations.AddField(
            model_name='article',
            name='is_comments_enabled',
            field=models.BooleanField(default=True, verbose_name='Is comments enabled'),
        ),
        migrations.AlterField(
            model_name='article',
            name='text',
            field=ckeditor_uploader.fields.RichTextUploadingField(max_length=10000, verbose_name='\u0422\u0435\u043a\u0441\u0442'),
        ),
    ]
